//	Lab 3: Rear bicycle light
//
//	This module is the top-level module for the rear bicycle light.
//
// The inputs to the module are a clock, and four buttons: left, right, up, and down.
// The outputs of the module are rear_light (the bicycle light following the specified
// behaviour) and a seven-segment display multiplexed to four outputs (determined by
// the select signal) indicating the speed in the fast and slow states.

module lab3 (clk, left_button, right_button, up_button, down_button, rear_light, display, select);
input clk;
input left_button, right_button, up_button, down_button;
output rear_light;
output [6:0] display;
output [1:0] select; 

wire [7:0] fast, slow;
wire reset = ~left_button;    // left button pushed to reset
wire progress_state;          // right button pushed to go to the next state
wire up;                      // up button pushed to increment speed modifier
wire down;                    // down button pushed to decrement speed modifier


// ******************************************************************************
//  Button processor units - synchronize, debouce and one-pulse button presses
//	******************************************************************************

button_press_unit bpu0(.clk(clk), .reset(reset), .in(~right_button), .out(progress_state));
button_press_unit bpu1(.clk(clk), .reset(reset), .in(~up_button), .out(up));
button_press_unit bpu2(.clk(clk), .reset(reset), .in(~down_button), .out(down));


// ******************************************************************************
//  Rear bicycle light FSM --- this is to be completed
//	******************************************************************************

bicycle_fsm fsm (.clk(clk), .reset(reset), .button(~down_button), .light(rear_light), .fast_speed(fast), .slow_speed(slow));


// ******************************************************************************
//  Multiplexed LED display --- this is to be expanded to multiplex four displays
//	******************************************************************************

multiplexed_display disp0 (.clk(clk), .s0(fast), .select(select), .display(display));

endmodule

