//	Multiplexed dual hexadecimal display
//
//	This module takes in two four-bit hexadecimal numbers and multiplexes
// the output to two LED displays on the Digilab Digital I/O 4 board using
// the module sevenseg to determine the corresponding seven-segment 
// configuration.
//
// A counter is used to divide the display time between each of the numbers. The
// output should switch fast enough between each of these numbers such that the 
// human eye only sees a continuous display.  Output flags are defined to indicate
// which of the numbers corresponds to the current display.
//
//	Last revision: Feb 03, 2007
// Revised by: jriley1@stanford.edu
// Revised Feb 07 2007 by davidbbs@stanford.edu


/* For this lab, you need to expand this to work for four displays (currently
   implemented for only two) */

module multiplexed_display (clk, s0, select, display);
input clk;
input [7:0] s0;                  // inputs 2 four-bit hexadecimal numbers
output [6:0] display;            // output seven-segment display for single hex number
output reg [1:0] select;         // output flags indicating which of the inputs is
                                 //      the current seven-seg output

parameter WIDTH = 18;
wire [WIDTH-1:0] count;
reg [3:0] s;
wire [6:0] sevenseg;


// counter used to divide display time
dff #(WIDTH) count_ff(.clk(clk), .d(count + 1), .q(count));

always @* begin
	if (count[WIDTH-1]) begin
		s = s0[7:4];
		select = 4'b01;
	end
	else begin
		s = s0[3:0];
		select = 4'b10;
	end
end
								  
// module hexadecimal_display is used to find the sevensegment configuration
// matching the current hexadecimal number
hexadecimal_display seg1 (s, sevenseg);

// the final output is inverted because the LED displays are active-low
assign display = ~sevenseg;

endmodule
